@@ -2,7 +2,8 @@
 #
 # Author: Thamme Gowda [tg (at) isi (dot) edu] 
 # Created: 5/13/20
-from mtdata.index import Index, Entry
+from mtdata.index import Index, Entry, DatasetId
+
 
 def load_all(index: Index):
 
@@ -18,7 +19,7 @@ def load_all(index: Index):
             f2 = f'*/{l1}-{l2}/{split}.{l1}-{l2}.{l2}'
             if split not in ('training', 'dict'):
                 f2 += '.0'
-            ent = Entry(langs=(l1, l2), url=url, name=f'JoshuaIndianCorpus_{split}',
-                  filename='joshua-indian-parallel-corpora.tar.gz',
+            ent = Entry(did=DatasetId(group='JoshuaDec', name=f'indian_{split}', version='1', langs=(l1, l2)),
+                  url=url, filename='joshua-indian-parallel-corpora.tar.gz',
                   in_paths=[f1, f2], in_ext='txt', cite=cite)
             index.add_entry(ent)
